==> stalker-0.1.1.a9.tar.gz: stalker-0.1.1.a9/stalker/core/errors.py <==
#-*- coding: utf-8 -*-
"""Errors for the system.

This module contains the Errors in Stalker.
"""






########################################################################
class LoginError(Exception):
    """Raised when the login information is not correct or not correlate with the data in the database.
    """
    
    
    
    #----------------------------------------------------------------------
    def __init__(self, value=""):
        self.value = value
    
    
    
    #----------------------------------------------------------------------
    def __str__(self):
        return repr(self.value)






########################################################################
class DBError(Exception):
    """Raised when there is no database and a database related action has been placed.
    """
    
    
    
    #----------------------------------------------------------------------
    def __init__(self, value=""):
        self.value = value
    
    
    
    #----------------------------------------------------------------------
    def __str__(self):
        return repr(self.value)






########################################################################
class CircularDependencyError(Exception):
    """Raised when there is cirular dependencies within Tasks
    """
    
    
    
    #----------------------------------------------------------------------
    def __init__(self, value=""):
        self.value = value
    
    
    
    #----------------------------------------------------------------------
    def __str__(self):
        return repr(self.value)

==> stalker-0.1.2.a3.tar.gz: stalker-0.1.2.a3/stalker/core/errors.py <==
#-*- coding: utf-8 -*-
"""Errors for the system.

This module contains the Errors in Stalker.
"""






########################################################################
class LoginError(Exception):
    """Raised when the login information is not correct or not correlate with the data in the database.
    """
    
    
    
    #----------------------------------------------------------------------
    def __init__(self, value=""):
        super(LoginError, self).__init__(value)
        self.value = value
    
    
    
    #----------------------------------------------------------------------
    def __str__(self):
        return repr(self.value)






########################################################################
class DBError(Exception):
    """Raised when there is no database and a database related action has been placed.
    """
    
    
    
    #----------------------------------------------------------------------
    def __init__(self, value=""):
        super(DBError, self).__init__(value)
        self.value = value
    
    
    
    #----------------------------------------------------------------------
    def __str__(self):
        return repr(self.value)






########################################################################
class CircularDependencyError(Exception):
    """Raised when there is cirular dependencies within Tasks
    """
    
    
    
    #----------------------------------------------------------------------
    def __init__(self, value=""):
        super(CircularDependencyError, self).__init__(value)
        self.value = value
    
    
    
    #----------------------------------------------------------------------
    def __str__(self):
        return repr(self.value)
